==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=id
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Memulihkan database',

	// I
	'info_restauration_sauvegarde' => 'memulihkan backup @archive@', # MODIF
	'info_sauvegarde' => 'Backup',
	'info_sauvegarde_reussi_02' => 'Database telah berhasil disimpan di @archive@. Anda dapat',
	'info_sauvegarde_reussi_03' => 'kembali ke manajemen',
	'info_sauvegarde_reussi_04' => 'situs anda.',

	// T
	'texte_admin_tech_01' => 'Opsi ini mengizinkan anda untuk menyimpan isi database ke dalam sebuah berkas di direktori @dossier@. Juga, mengingatkan anda untuk mengambil seluruh direktori @img@, yang berisikan gambar-gambar dan dokumen-dokumen yang digunakan dalam artikel dan bagian.',
	'texte_admin_tech_02' => 'Peringatan: backup ini HANYA dapat dipulihkan dalam sebuah situs yang diinstal dalam versi yang sama dengan SPIP. Anda seharusnya tidak mengosongkan database dan diharapkan menginstal kembali backup setelah pembaharuan... Untuk informasi lebih lanjut silakan membaca <a href="@spipnet@">dokumentasi SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Pulihkan isi backup database',
	'texte_restaurer_sauvegarde' => 'Opsi ini mengizinkan anda untuk memulihkan backup database
sebelumnya. Untuk melakukannya, berkas yang berisikan backup harus disimpan di
direktori @dossier@.
Berhati-hatilah dengan fitur ini: <b>Setiap modifikasi atau kerusakan tidak
dapat dipulihkan kembali.</b>', # MODIF
	'texte_sauvegarde' => 'Backup isi database',
	'texte_sauvegarde_base' => 'Backup database'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=id
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Memulihkan database',

	// I
	'info_restauration_sauvegarde' => 'memulihkan backup @archive@', # MODIF
	'info_sauvegarde' => 'Backup',
	'info_sauvegarde_reussi_02' => 'Database telah berhasil disimpan di @archive@. Anda dapat',
	'info_sauvegarde_reussi_03' => 'kembali ke manajemen',
	'info_sauvegarde_reussi_04' => 'situs anda.',

	// T
	'texte_admin_tech_01' => 'Opsi ini mengizinkan anda untuk menyimpan isi database ke dalam sebuah berkas di direktori @dossier@. Juga, mengingatkan anda untuk mengambil seluruh direktori @img@, yang berisikan gambar-gambar dan dokumen-dokumen yang digunakan dalam artikel dan bagian.',
	'texte_admin_tech_02' => 'Peringatan: backup ini HANYA dapat dipulihkan dalam sebuah situs yang diinstal dalam versi yang sama dengan SPIP. Anda seharusnya tidak mengosongkan database dan diharapkan menginstal kembali backup setelah pembaharuan... Untuk informasi lebih lanjut silakan membaca <a href="@spipnet@">dokumentasi SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Pulihkan isi backup database',
	'texte_restaurer_sauvegarde' => 'Opsi ini mengizinkan anda untuk memulihkan backup database
sebelumnya. Untuk melakukannya, berkas yang berisikan backup harus disimpan di
direktori @dossier@.
Berhati-hatilah dengan fitur ini: <b>Setiap modifikasi atau kerusakan tidak
dapat dipulihkan kembali.</b>', # MODIF
	'texte_sauvegarde' => 'Backup isi database',
	'texte_sauvegarde_base' => 'Backup database',
];
